@@ -1,10 +1,20 @@
-import sys, re, hashlib, os
+import sys, hashlib, os
 from PIL import Image, ImageOps
 from .util import *
 
 
-def sha_512_mode(input, bypass, debug, console, invert):
-    if not input:
+def sha_512_mode(input, bypass, debug, console, tile, invert, file, outputfile, svg):
+
+    if file:
+        BLOCKSIZE = 0x1000
+        hasher = hashlib.sha512()
+        with open(file, "rb") as tfile:
+            buffer = tfile.read(BLOCKSIZE)
+            while len(buffer) > 0:
+                hasher.update(buffer)
+                buffer = tfile.read(BLOCKSIZE)
+        hash = hasher.hexdigest().lower()
+    elif not input:
         hash = (
             hashlib.sha512(sys.stdin.read().encode()).hexdigest()
             if not bypass
@@ -14,36 +24,28 @@ def sha_512_mode(input, bypass, debug, console, invert):
         hash = (
             hashlib.sha512(" ".join(input).encode()).hexdigest()
             if not bypass
-            else input.lower()
+            else input[0].lower()
         )
 
-    pattern = re.compile(r"^[a-f0-9]{128}$")
-    match = pattern.match(hash)
-    if not match:
-        sys.stderr.write(f"{hash} is not a valid SHA512 hash\n")
-        sys.exit(-1)
+    validity_check(hash=hash, regex_str=r"^[a-f0-9]{128}$", name="SHA512")
 
     if debug:
-        sys.stdout.write(
-            f'hashpic: "{input}" will be following hash: {hash}\n'
-            if not bypass
-            else f"hashpic: directly given hash: {input}\n"
+        debug_log(input=input, hash=hash, bypass=bypass)
+
+    if svg:
+        svg_mode(
+            hash=hash,
+            size=0x400,
+            digest_length=0x40,
+            invert=invert,
+            debug=debug,
+            outputfile=outputfile,
         )
 
     if console:
-        chunks = chunk_it(chunk_it(hash), 8)
+        print_to_console(hash, invert, tile)
 
-        for i in chunks:
-            for j in i:
-                sys.stdout.write(
-                    f"\033[38;5;{0xff - int(j, 16) if invert else int(j, 16)}m{j}\u001b[0m"
-                )
-            sys.stdout.write("\n")
-        sys.exit(0)
-
-    colors = []
-    for i in chunk_it(hash):
-        colors.append(convert_term_to_rgb(int(i, 16)))
+    colors = hash_to_color_codes(hash)
 
     width = 1024
     height = 1024
@@ -189,6 +191,6 @@ def sha_512_mode(input, bypass, debug, console, invert):
     if debug:
         im.show()
 
-    im.save(os.getcwd() + "/output.png")
+    im.save(os.getcwd() + "/" + outputfile)
 
     sys.exit(0)
